'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var FastifySession = _interopDefault(require('fastify-session'));
var MemoryStore = _interopDefault(require('memorystore'));
require('fastify-cookie');
var server = require('@harmonyjs/server');

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

const ControllerAuthenticationSession = configuration => ({
  name: 'ControllerAuthenticationJWT',
  global: true,

  async initialize({
    server: server$1,
    logger
  }) {
    const {
      secret,
      saveUninitialized,
      store
    } = configuration;

    if (!secret) {
      logger.warn('Please avoid using the default secret for authentication.');
      logger.warn('Provide your own secret through AuthenticationSessionConfig::secret');
    }

    await server$1.register(FastifySession, _objectSpread2(_objectSpread2({}, configuration), {}, {
      secret: secret || 'harmony-default-auth-session-secret',
      store: store || new MemoryStore({
        checkPeriod: 24 * 60 * 60 * 1000
      }),
      saveUninitialized: saveUninitialized || false
    }));
    await server$1.decorate(ControllerAuthenticationSession.validator, {
      block: async (request, reply) => {
        if (!request.session || !request.session.payload) {
          reply.send(server.HttpErrors.Unauthorized('No session found'));
        }
      },
      try: async () => {// Do nothing
      },
      get: request => request.session && request.session.payload,
      create: (request, reply, payload) => {
        request.session.payload = payload;
      }
    });
    logger.info('Authentication system initialized');
  }

});

ControllerAuthenticationSession.validator = 'sessionAuthenticate';

exports.default = ControllerAuthenticationSession;
//# sourceMappingURL=index.js.map
